package com.qmth.eds.api;

import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.eds.common.contant.SystemConstant;
import com.qmth.eds.common.entity.ExamSemester;
import com.qmth.eds.common.util.Result;
import com.qmth.eds.common.util.ResultUtil;
import com.qmth.eds.service.ExamSemesterService;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.constraints.Max;
import javax.validation.constraints.Min;

@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/exam_semester")
public class ExamSemesterController {

    @Resource
    private ExamSemesterService examSemesterService;

    /**
     * 查询
     *
     * @param pageNumber 分页参数
     * @param pageSize   分页参数
     */
    @ApiOperation(value = "分页")
    @PostMapping("/page")
    public Result page(@RequestParam(value = "schoolId") Long schoolId,
                       @RequestParam @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                       @RequestParam @Min(SystemConstant.PAGE_SIZE_MIN) @Max(SystemConstant.PAGE_SIZE_MAX) Integer pageSize) {
        return ResultUtil.ok(examSemesterService.pageData(schoolId, pageNumber, pageSize));
    }

    /**
     * 查询
     */
    @ApiOperation(value = "查询")
    @PostMapping("/list")
    public Result list(@RequestParam(value = "schoolId") Long schoolId) {
        return ResultUtil.ok(examSemesterService.listBySchoolId(schoolId));
    }

    /**
     * 新增/修改
     *
     * @param examSemester 学期
     */
    @ApiOperation(value = "新增/修改")
    @PostMapping("/save")
    public Result save(@RequestParam(value = "examSemester", required = false) ExamSemester examSemester) {
        return ResultUtil.ok(examSemesterService.saveData(examSemester));
    }

    /**
     * 删除
     *
     * @param id ID
     */
    @ApiOperation(value = "删除")
    @PostMapping("/delete")
    public Result delete(@RequestParam(value = "id") Long id) {
        return ResultUtil.ok(examSemesterService.delete(id));
    }

}
